@@ -14,16 +14,18 @@
 #ifndef SDLPLAYER_H
 #define SDLPLAYER_H
 
-#ifdef _WIN32
-	#include <SDL.h>
+#include "configfile.h"
+
+#if (defined _WIN32) || (defined __APPLE__)
 	#include <SDL_mixer.h>
 #else
-	#include <SDL/SDL.h>
 	#include <SDL/SDL_mixer.h>
 #endif
 
+#include <iostream>
 #include <string>
-#include "configfile.h"
+
+// struct Mix_Chunk;
 
 /**
 	@author FThauer FHammer <webmaster@pokerth.net>
@@ -43,17 +45,14 @@ public:
 
 private:
 
-	int audio_rate;
-	Uint16 audio_format;
-	int audio_channels;
-	int audio_buffers;
 	Mix_Chunk *sound;
-	Uint8 *soundData;
+	unsigned char *soundData;
 	int currentChannel;
 
 	bool audioEnabled;
 
 	ConfigFile *myConfig;
+	QString myAppDataPath;
 
 };
 
